@@ -201,7 +201,7 @@ def construct(cls: Type[U], args_as_cfg: Mapping, **kwargs) -> U:
     if isinstance(args_as_cfg, Mapping):
         args = dict(args_as_cfg)
         for name, value in args.items():
-            if isinstance(value, Mapping):
+            if isinstance(value, Mapping) and ("()" in value or "class" in value):
                 args[name] = construct_from_config(value)
         for k, v in kwargs.items():
             args[k] = v
